﻿-- Author      : RisM
-- Create Date : 9/21/2009 11:52:56 PM

local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L	= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell", false)
local LDB = LibStub:GetLibrary("LibDataBroker-1.1")
local LDBIcon = LDB and LibStub("LibDBIcon-1.0", true)

SpeakinSpell:PrintLoading("gui/minimapbutton.lua")


-------------------------------------------------------------------------------
-- SetIcon extension to LDBIcon
-------------------------------------------------------------------------------


function LDBIcon:SetIcon(name, newicon)
	local button = LDBIcon.objects[name]
	button.icon:SetTexture(newicon)
	--TODOFUTURE: is it possible to get the icon to change in the Titan Panel also?
end


-------------------------------------------------------------------------------
-- MINIMAP BUTTON SUPPORT
-------------------------------------------------------------------------------


function SpeakinSpell:MinimapButton_Create()
	local funcname = "MinimapButton_Create"
	
	if not (LDB and LDBIcon) then
		return
	end
	
	-- define which icons we'll use
	SpeakinSpell.iconpaths = {
		ON = "Interface\\Icons\\Ability_Warrior_BattleShout", --recognizable i guess
		OFF = "Interface\\Icons\\Ability_Rogue_Disguise", --this is OK for off
	}
	
	-- LDB launcher
	--self:DebugMsg(funcname,"entry")
	SpeakinSpell.Minimap = {
		Icon = {
			hide = false,
			minimapPos = 220,
			radius = 80,
		},
		Launcher = LDB:NewDataObject("SpeakinSpell", {
			type = "launcher",
			icon = SpeakinSpell.iconpaths.ON,
			OnClick = function(clickedframe, button)
				SpeakinSpell:MinimapButton_OnClick(clickedframe, button)
			end,
			OnTooltipShow = function(tt)
				local line = "SpeakinSpell"
				if SpeakinSpellSavedData.EnableAllMessages then
					line = line..tostring(SpeakinSpell.Colors.ON)..L[" is ON"]
				else
					line = line..tostring(SpeakinSpell.Colors.OFF)..L[" is OFF"]
				end
				tt:AddLine(line)
				tt:AddLine( tostring(SpeakinSpell.Colors.ClickHighlight) .. L["Click|r to toggle SpeakinSpell on/off"])
				tt:AddLine( tostring(SpeakinSpell.Colors.ClickHighlight) .. L["Right-click|r to open the options"])
			end,
		}),
		Registered = false,
	}

	if SpeakinSpellSavedData.ShowMinimapButton then 
		self:MinimapButton_Register()
	end
end


function SpeakinSpell:MinimapButton_Register()
	local funcname = "MinimapButton_Register"
	--self:DebugMsg(funcname,"Register")
	SpeakinSpell.Minimap.Registered = true
	LDBIcon:Register("SpeakinSpell", SpeakinSpell.Minimap.Launcher, SpeakinSpell.Minimap.Icon)
end


function SpeakinSpell:MinimapButton_OnClick(clickedframe, button)
	if button == "RightButton" then 
		SpeakinSpell:ShowOptions_Toggle() 
	else 
		SpeakinSpellSavedData.EnableAllMessages = not SpeakinSpellSavedData.EnableAllMessages
		self:MinimapButton_Refresh()
		self:RefreshFrame("General")
	end
end


function SpeakinSpell:MinimapButton_Refresh()
	local funcname = "MinimapButton_Refresh"

	if SpeakinSpellSavedData.ShowMinimapButton then 
		if not SpeakinSpell.Minimap.Registered then
			self:MinimapButton_Register()
		end
		
		-- make sure the button is showing
		--self:DebugMsg(funcname, "show")
		LDBIcon:Show("SpeakinSpell") 
		
		-- show a different icon to indicate on/off status
		local icon = SpeakinSpell.iconpaths.OFF
		if SpeakinSpellSavedData.EnableAllMessages then
			icon = SpeakinSpell.iconpaths.ON
		end
		--self:DebugMsg(funcname, "setting icon:"..tostring(icon))
		LDBIcon:SetIcon("SpeakinSpell", icon) 
	else 
		-- make sure the button is hidden
		--self:DebugMsg(funcname, "hide")
		LDBIcon:Hide("SpeakinSpell") 
	end
end



function SpeakinSpell:MinimapButton_Show(show)
	SpeakinSpellSavedData.ShowMinimapButton = show
	self:MinimapButton_Refresh()
end

